@@ -289,6 +289,46 @@ static const MetaKeyHandler screen_handlers[] = {
     GINT_TO_POINTER (10) },
   { META_KEYBINDING_COMMAND_12, handle_run_command,
     GINT_TO_POINTER (11) },
+  { META_KEYBINDING_COMMAND_13, handle_run_command,
+    GINT_TO_POINTER (12) },
+  { META_KEYBINDING_COMMAND_14, handle_run_command,
+    GINT_TO_POINTER (13) },
+  { META_KEYBINDING_COMMAND_15, handle_run_command,
+    GINT_TO_POINTER (14) },
+  { META_KEYBINDING_COMMAND_16, handle_run_command,
+    GINT_TO_POINTER (15) },
+  { META_KEYBINDING_COMMAND_17, handle_run_command,
+    GINT_TO_POINTER (16) },
+  { META_KEYBINDING_COMMAND_18, handle_run_command,
+    GINT_TO_POINTER (17) },
+  { META_KEYBINDING_COMMAND_19, handle_run_command,
+    GINT_TO_POINTER (18) },
+  { META_KEYBINDING_COMMAND_20, handle_run_command,
+    GINT_TO_POINTER (19) },
+  { META_KEYBINDING_COMMAND_21, handle_run_command,
+    GINT_TO_POINTER (20) },
+  { META_KEYBINDING_COMMAND_22, handle_run_command,
+    GINT_TO_POINTER (21) },
+  { META_KEYBINDING_COMMAND_23, handle_run_command,
+    GINT_TO_POINTER (22) },
+  { META_KEYBINDING_COMMAND_24, handle_run_command,
+    GINT_TO_POINTER (23) },
+  { META_KEYBINDING_COMMAND_25, handle_run_command,
+    GINT_TO_POINTER (24) },
+  { META_KEYBINDING_COMMAND_26, handle_run_command,
+    GINT_TO_POINTER (25) },
+  { META_KEYBINDING_COMMAND_27, handle_run_command,
+    GINT_TO_POINTER (26) },
+  { META_KEYBINDING_COMMAND_28, handle_run_command,
+    GINT_TO_POINTER (27) },
+  { META_KEYBINDING_COMMAND_29, handle_run_command,
+    GINT_TO_POINTER (28) },
+  { META_KEYBINDING_COMMAND_30, handle_run_command,
+    GINT_TO_POINTER (29) },
+  { META_KEYBINDING_COMMAND_31, handle_run_command,
+    GINT_TO_POINTER (30) },
+  { META_KEYBINDING_COMMAND_32, handle_run_command,
+    GINT_TO_POINTER (31) },
   { NULL, NULL, NULL }
 };
   
@@ -407,7 +447,7 @@ reload_modmap (MetaDisplay *display)
                   str = XKeysymToString (syms[j]);
                   meta_topic (META_DEBUG_KEYBINDINGS,
                               "Keysym %s bound to modifier 0x%x\n",
-                              str ? str : "(null)",
+                              str ? str : "none",
                               (1 << ( i / modmap->max_keypermod)));
                 }
               
@@ -1380,7 +1420,7 @@ meta_display_process_key_event (MetaDisplay *display,
   meta_topic (META_DEBUG_KEYBINDINGS,
               "Processing key %s event, keysym: %s state: 0x%x window: %s\n",
               event->type == KeyPress ? "press" : "release",
-              str ? str : "(null)", event->xkey.state,
+              str ? str : "none", event->xkey.state,
               window ? window->desc : "(no window)");
 
   all_keys_grabbed = window ? window->all_keys_grabbed : screen->all_keys_grabbed;
